@@ -258,7 +258,7 @@ public:
 	 * @param state internal state code
 	 * @return user-readable state string
 	 */
-	string convertStateBackStr(char state);
+	string convertStateBackStr(StateType state);
 
 	/**
             get alignment site range from the residue range relative to a sequence
@@ -332,6 +332,11 @@ public:
      */
     virtual void getPatternFreq(IntVector &freq);
 
+    /**
+     * @param[out] freq vector of site-pattern frequencies
+     */
+    virtual void getPatternFreq(int *freq);
+
     /**
             @param i sequence index
             @return sequence name
