@@ -8,7 +8,7 @@
 #ifndef MODELCODON_H_
 #define MODELCODON_H_
 
-#include "modelgtr.h"
+#include "modelmarkov.h"
 
 /** CF_TARGET_NT: frequency of target nucleotide is multiplied with the rate entry (Muse and Gaut 1994)
     CF_TARGET_CODON: frequency of target codon is multiplied with the rate entry (Goldman Yang 1994)
@@ -33,7 +33,7 @@ const int CA_TRANSITION_3NT   = 2048; // codon substitution involve the 3rd NT w
 /**
  * Codon substitution models
  */
-class ModelCodon: public ModelGTR {
+class ModelCodon: public ModelMarkov {
 public:
 	/**
 		constructor
@@ -42,13 +42,18 @@ public:
 		@param tree associated phylogenetic tree
 	*/
 	ModelCodon(const char *model_name, string model_params, StateFreqType freq, string freq_params,
-    		PhyloTree *tree, bool count_rates = true);
+    		PhyloTree *tree);
 
 	/**
 	 * destructor
 	 */
 	virtual ~ModelCodon();
 
+    /**
+        start structure for checkpointing
+    */
+    virtual void startCheckpoint();
+
     /**
         save object into the checkpoint
     */
@@ -91,15 +96,24 @@ public:
 	/**
 	 * read codon model from a stream, modying rates and state_freq accordingly
 	 * @param in input stream containing lower triangular matrix of rates, frequencies and list of codons
+     * @reset_params true to reset parameters, false otherwise
 	 */
 	void readCodonModel(istream &in, bool reset_params);
 
 	/**
 	 * read codon model from a string, modying rates and state_freq accordingly
 	 * @param str input string containing lower triangular matrix of rates, frequencies and list of codons
+     * @reset_params true to reset parameters, false otherwise
 	 */
 	void readCodonModel(string &str, bool reset_params);
 
+	/**
+	 * read codon model from a file in PAML format
+	 * @param filename input file containing lower triangular matrix of rates, frequencies and list of codons
+     * @reset_params true to reset parameters, false otherwise
+	 */
+    void readCodonModelFile(const char *filename, bool reset_params);
+
 	/**
 		write information
 		@param out output stream
