@@ -22,6 +22,11 @@ public:
 
 	virtual ~RateFree();
 
+    /**
+        start structure for checkpointing
+    */
+    virtual void startCheckpoint();
+
     /**
         save object into the checkpoint
     */
@@ -97,9 +102,9 @@ public:
 	virtual void setNCategory(int ncat);
 
     /**
-        initialize rates and prop from rate model with #category less by 1
+        initialize from checkpoint rates and prop from rate model with #category-1
     */
-    void setRateAndProp(RateFree *input);
+    virtual void initFromCatMinusOne();
 
 	/**
 	 * used to normal branch lengths if mean rate is not equal to 1 (e.g. FreeRate model)
@@ -135,8 +140,8 @@ protected:
 	 */
 	double *prop;
 
-	/** TRUE to fix parameters */
-	bool fix_params;
+	/** 1 to fix weights, 2 to fix both weights and rates */
+	int fix_params;
     
     /** true to sort rate in increasing order, false otherwise */
     bool sorted_rates;
