@@ -46,6 +46,11 @@ public:
         return true;
     }
 
+    /**
+        start structure for checkpointing
+    */
+    virtual void startCheckpoint();
+
     /**
         save object into the checkpoint
     */
