@@ -921,7 +921,8 @@ void PhyloTree::computeQuartetLikelihoods(vector<QuartetInfo> &lmap_quartet_info
             // set up parameters
             quartet_tree->setParams(params);
             quartet_tree->optimize_by_newton = params->optimize_by_newton;
-            quartet_tree->setLikelihoodKernel(params->SSE, num_threads);
+            quartet_tree->setLikelihoodKernel(params->SSE);
+            quartet_tree->setNumThreads(num_threads);
 
             // set up partition model
             if (isSuperTree()) {
@@ -1535,7 +1536,7 @@ void PhyloTree::reportLikelihoodMapping(ofstream &out) {
 	out << "---------------------------" << endl << endl;
 	out << "Number of quartets: " << params->lmap_num_quartets;
     if (params->lmap_num_quartets < LMGroups.uniqueQuarts)
-        cout << " (randomly chosen with replacement from " 
+        out << " (randomly chosen with replacement from "
 		<< LMGroups.uniqueQuarts << " existing unique quartets)" << endl << endl;
     else
         out << " (all unique quartets)" << endl << endl;
